Merge staging-next into staging

main
github-actions[bot] 2 years ago committed by GitHub
commit 51ebf5849e
No known key found for this signature in database
GPG Key ID: 4AEE18F83AFDEB23
  1. 4
      nixos/modules/services/monitoring/mimir.nix
  2. 1
      nixos/tests/all-tests.nix
  3. 50
      nixos/tests/grafana-mimir.nix
  4. 4
      pkgs/applications/blockchains/bisq-desktop/default.nix
  5. 5
      pkgs/applications/editors/ghostwriter/default.nix
  6. 6
      pkgs/applications/editors/helix/default.nix
  7. 8
      pkgs/applications/networking/cluster/argocd-autopilot/default.nix
  8. 4
      pkgs/applications/networking/protonvpn-cli/default.nix
  9. 6
      pkgs/applications/networking/protonvpn-gui/default.nix
  10. 2
      pkgs/applications/science/logic/beluga/default.nix
  11. 4
      pkgs/desktops/gnome/core/gnome-terminal/default.nix
  12. 4
      pkgs/desktops/gnome/games/aisleriot/default.nix
  13. 2
      pkgs/development/compilers/fstar/default.nix
  14. 11
      pkgs/development/compilers/gcc/12/default.nix
  15. 4
      pkgs/development/compilers/haxe/default.nix
  16. 4
      pkgs/development/ocaml-modules/higlo/default.nix
  17. 4
      pkgs/development/ocaml-modules/iri/default.nix
  18. 4
      pkgs/development/ocaml-modules/piqi/default.nix
  19. 67
      pkgs/development/ocaml-modules/sedlex/2.nix
  20. 64
      pkgs/development/ocaml-modules/sedlex/default.nix
  21. 4
      pkgs/development/ocaml-modules/xtmpl/default.nix
  22. 4
      pkgs/development/python-modules/mkdocs-material/default.nix
  23. 4
      pkgs/development/python-modules/mlflow/default.nix
  24. 4
      pkgs/development/python-modules/protonvpn-nm-lib/default.nix
  25. 4
      pkgs/development/python-modules/python-gitlab/default.nix
  26. 7
      pkgs/development/tools/analysis/checkov/default.nix
  27. 2
      pkgs/development/tools/analysis/flow/default.nix
  28. 6
      pkgs/development/tools/yq-go/default.nix
  29. 93
      pkgs/games/srb2/default.nix
  30. 72
      pkgs/games/srb2/wadlocation.patch
  31. 88
      pkgs/games/srb2kart/default.nix
  32. 61
      pkgs/games/srb2kart/wadlocation.patch
  33. 14
      pkgs/misc/uboot/0001-configs-rpi-allow-for-bigger-kernels.patch
  34. 15
      pkgs/servers/monitoring/mimir/default.nix
  35. 21
      pkgs/test/config.nix
  36. 2
      pkgs/test/default.nix
  37. 2
      pkgs/tools/audio/liquidsoap/full.nix
  38. 4
      pkgs/tools/misc/diffoscope/default.nix
  39. 35
      pkgs/tools/networking/ngrok-1/default.nix
  40. 101
      pkgs/tools/networking/ngrok-1/deps.nix
  41. 6
      pkgs/tools/networking/shadowsocks-rust/default.nix
  42. 6
      pkgs/top-level/all-packages.nix
  43. 2
      pkgs/top-level/config.nix
  44. 2
      pkgs/top-level/ocaml-packages.nix

@ -28,6 +28,9 @@ in {
};
config = mkIf cfg.enable {
# for mimirtool
environment.systemPackages = [ pkgs.mimir ];
assertions = [{
assertion = (
(cfg.configuration == {} -> cfg.configFile != null) &&
@ -56,6 +59,7 @@ in {
ProtectSystem = "full";
DevicePolicy = "closed";
NoNewPrivileges = true;
WorkingDirectory = "/var/lib/mimir";
StateDirectory = "mimir";
};
};

@ -170,6 +170,7 @@ in
frr = handleTest ./frr.nix {};
fsck = handleTest ./fsck.nix {};
ft2-clone = handleTest ./ft2-clone.nix {};
grafana-mimir = handleTest ./grafana-mimir.nix {};
gerrit = handleTest ./gerrit.nix {};
geth = handleTest ./geth.nix {};
ghostunnel = handleTest ./ghostunnel.nix {};

@ -0,0 +1,50 @@
import ./make-test-python.nix ({ pkgs, ... }: {
name = "grafana-mimir";
nodes = {
server = { ... }: {
environment.systemPackages = [ pkgs.jq ];
services.mimir.enable = true;
services.mimir.configuration = {
ingester.ring.replication_factor = 1;
};
services.telegraf.enable = true;
services.telegraf.extraConfig = {
agent.interval = "1s";
agent.flush_interval = "1s";
inputs.exec = {
commands = [
"${pkgs.coreutils}/bin/echo 'foo i=42i'"
];
data_format = "influx";
};
outputs = {
http = {
# test remote write
url = "http://localhost:8080/api/v1/push";
# Data format to output.
data_format = "prometheusremotewrite";
headers = {
Content-Type = "application/x-protobuf";
Content-Encoding = "snappy";
X-Scope-OrgID = "nixos";
X-Prometheus-Remote-Write-Version = "0.1.0";
};
};
};
};
};
};
testScript = ''
start_all()
server.wait_for_unit("mimir.service")
server.wait_for_unit("telegraf.service")
server.wait_for_open_port(8080)
server.wait_until_succeeds(
"curl -H 'X-Scope-OrgID: nixos' http://127.0.0.1:8080/prometheus/api/v1/label/host/values | jq -r '.data[0]' | grep server"
)
'';
})

@ -34,11 +34,11 @@ let
in
stdenv.mkDerivation rec {
pname = "bisq-desktop";
version = "1.8.4";
version = "1.9.1";
src = fetchurl {
url = "https://github.com/bisq-network/bisq/releases/download/v${version}/Bisq-64bit-${version}.deb";
sha256 = "09bpkmn22kal3cxg8sil02wy2f2gplsbdkp4viagn0jppma02jid";
sha256 = "0gzfcp255z542adk1g6gsmfpp5zpivv6n1f5kzqgwgm5qmr24049";
};
nativeBuildInputs = [ makeWrapper copyDesktopItems imagemagick dpkg zip xz ];

@ -14,13 +14,13 @@
mkDerivation rec {
pname = "ghostwriter";
version = "2.1.2";
version = "2.1.3";
src = fetchFromGitHub {
owner = "wereturtle";
repo = pname;
rev = version;
hash = "sha256-NpgtxYqxMWMZXZRZjujob40Nn6hirsSzcjoqRJR6Rws=";
hash = "sha256-U6evyaC7fLFyKzeDNAI3U3/IcCk8DTY8pb3e3xqSfwk=";
};
nativeBuildInputs = [ qmake pkg-config qttools ];
@ -34,6 +34,7 @@ mkDerivation rec {
meta = with lib; {
description = "A cross-platform, aesthetic, distraction-free Markdown editor";
homepage = src.meta.homepage;
changelog = "https://github.com/wereturtle/ghostwriter/blob/${src.rev}/CHANGELOG.md";
license = licenses.gpl3Plus;
platforms = platforms.unix;
maintainers = with maintainers; [ dotlambda erictapen ];

@ -2,17 +2,17 @@
rustPlatform.buildRustPackage rec {
pname = "helix";
version = "22.03";
version = "22.05";
# This release tarball includes source code for the tree-sitter grammars,
# which is not ordinarily part of the repository.
src = fetchzip {
url = "https://github.com/helix-editor/helix/releases/download/${version}/helix-${version}-source.tar.xz";
sha256 = "DP/hh6JfnyHdW2bg0cvhwlWvruNDvL9bmXM46iAUQzA=";
sha256 = "sha256-MVHfj9iVC8rFGFU+kpRcH0qX9kQ+scFsRgSw7suC5RU=";
stripRoot = false;
};
cargoSha256 = "zJQ+KvO+6iUIb0eJ+LnMbitxaqTxfqgu7XXj3j0GiX4=";
cargoSha256 = "sha256-9jkSZ2yW0Pca1ats7Mgv7HprpjoZWLpsbuwMjYOKlmk=";
nativeBuildInputs = [ makeWrapper ];

@ -2,16 +2,16 @@
buildGoModule rec {
pname = "argocd-autopilot";
version = "0.3.5";
version = "0.3.7";
src = fetchFromGitHub {
owner = "argoproj-labs";
repo = "argocd-autopilot";
rev = "v${version}";
sha256 = "sha256-YqnmtDVtprQQFbL++X9rUJFGj+fMD+fvDRWsQ+uOxxo=";
sha256 = "sha256-dLmJQCASdWkzWOPQ0bdJLe2AD06+L2ghP2yWry1XL1k=";
};
vendorSha256 = "sha256-r8RTwMzFS/BkxW08+wfAovuFLpIOReDsuHi/Hx9cVPc=";
vendorSha256 = "sha256-0v/HTiQf/mZUU1b55jAnSj86NEFOUaiM+/MrVvwJYBM=";
proxyVendor = true;
@ -24,7 +24,7 @@ buildGoModule rec {
"-X ${package_url}.version=${src.rev}"
"-X ${package_url}.buildDate=unknown"
"-X ${package_url}.gitCommit=${src.rev}"
"-X ${package_url}.installationManifestURL=github.com/argoproj-labs/argocd-autopilot/manifests/base?ref=${src.rev}"
"-X ${package_url}.installationManifestsURL=github.com/argoproj-labs/argocd-autopilot/manifests/base?ref=${src.rev}"
"-X ${package_url}.installationManifestsNamespacedURL=github.com/argoproj-labs/argocd-autopilot/manifests/insecure?ref=${src.rev}"
];

@ -9,7 +9,7 @@
buildPythonApplication rec {
pname = "protonvpn-cli";
version = "3.11.1";
version = "3.12.0";
format = "setuptools";
disabled = pythonOlder "3.5";
@ -18,7 +18,7 @@ buildPythonApplication rec {
owner = "protonvpn";
repo = "linux-cli";
rev = version;
sha256 = "sha256-u+POtUz7NoGS23aOmvDCZPUp2HW1xXGtfbZR88cWCBc=";
sha256 = "sha256-z0ewAqf8hjyExqBN8KBsDwJ+SA/pIBYZhKtXF9M65HE=";
};
propagatedBuildInputs = [

@ -17,13 +17,13 @@
buildPythonApplication rec {
pname = "protonvpn-gui";
version = "1.8.0";
version = "1.9.0";
src = fetchFromGitHub {
owner = "ProtonVPN";
repo = "linux-app";
rev = "refs/tags/${version}";
sha256 = "sha256-Od12qHiyXHu2JnjYV7amZz5xxL+eiWUVbcG5Tbcrr28=";
rev = version;
sha256 = "sha256-+YLrIhe7kzQHPRk/3D1r56ESS1BdDxP1PFeNIg/kGLw=";
};
nativeBuildInputs = [

@ -14,7 +14,7 @@ ocamlPackages.buildDunePackage rec {
useDune2 = true;
buildInputs = with ocamlPackages; [
gen sedlex_2 ocaml_extlib dune-build-info linenoise
gen sedlex ocaml_extlib dune-build-info linenoise
];
postPatch = ''

@ -28,11 +28,11 @@
stdenv.mkDerivation rec {
pname = "gnome-terminal";
version = "3.44.0";
version = "3.44.1";
src = fetchurl {
url = "mirror://gnome/sources/gnome-terminal/${lib.versions.majorMinor version}/${pname}-${version}.tar.xz";
sha256 = "qpZxie62CUWebApGigHqcMuMRTDaHVALLT9PxDi4/io=";
sha256 = "+28g7h/yMamq7asT1dxuWmTJVXESJISLeQCG6IlZ03s=";
};
nativeBuildInputs = [

@ -19,14 +19,14 @@
stdenv.mkDerivation rec {
pname = "aisleriot";
version = "3.22.22";
version = "3.22.23";
src = fetchFromGitLab {
domain = "gitlab.gnome.org";
owner = "GNOME";
repo = pname;
rev = version;
sha256 = "sha256-Jr4XEj6h+gI1gNqoJ/cJ3cDBB4mSbpzvOUQkwGxkLPs=";
sha256 = "sha256-s7z1bR2ZG3YxJcqNrhH+O5PfGeFoPWeWSI26VCCe33Y=";
};
nativeBuildInputs = [

@ -33,7 +33,7 @@ stdenv.mkDerivation rec {
fileutils
menhirLib
pprint
sedlex_2
sedlex
ppxlib
ppx_deriving
ppx_deriving_yojson

@ -3,6 +3,7 @@
, langAda ? false
, langObjC ? stdenv.targetPlatform.isDarwin
, langObjCpp ? stdenv.targetPlatform.isDarwin
, langD ? false
, langGo ? false
, reproducibleBuild ? true
, profiledCompiler ? false
@ -41,6 +42,10 @@ assert stdenv.hostPlatform.isDarwin -> gnused != null;
assert langGo -> langCC;
assert langAda -> gnatboot != null;
# TODO: fixup D bootstapping, probably by using gdc11 (and maybe other changes).
# error: GDC is required to build d
assert !langD;
# threadsCross is just for MinGW
assert threadsCross != null -> stdenv.targetPlatform.isWindows;
@ -68,6 +73,7 @@ let majorVersion = "12";
url = "https://github.com/fxcoudert/gcc/compare/releases/gcc-11.1.0...gcc-11.1.0-arm-20210504.diff";
sha256 = "sha256-JqCGJAfbOxSmkNyq49aFHteK/RFsCSLQrL9mzUCnaD0=";
})
++ optional langD ../libphobos.patch
# Obtain latest patch with ../update-mcfgthread-patches.sh
++ optional (!crossStageStatic && targetPlatform.isMinGW) ./Added-mcf-thread-model-support-from-mcfgthread.patch;
@ -208,6 +214,7 @@ stdenv.mkDerivation ({
enableShared
langC
langD
langCC
langFortran
langAda
@ -248,14 +255,14 @@ stdenv.mkDerivation ({
inherit
(import ../common/extra-target-flags.nix {
inherit lib stdenv crossStageStatic libcCross threadsCross;
inherit lib stdenv crossStageStatic langD libcCross threadsCross;
})
EXTRA_FLAGS_FOR_TARGET
EXTRA_LDFLAGS_FOR_TARGET
;
passthru = {
inherit langC langCC langObjC langObjCpp langAda langFortran langGo version;
inherit langC langCC langObjC langObjCpp langAda langFortran langGo langD version;
isGNU = true;
};

@ -6,7 +6,7 @@ let
then with ocaml-ng.ocamlPackages_4_12; [
ocaml
findlib
sedlex_2
sedlex
xml-light
ptmap
camlp5
@ -18,7 +18,7 @@ let
then with ocaml-ng.ocamlPackages_4_10; [
ocaml
findlib
sedlex_2
sedlex
xml-light
ptmap
camlp5

@ -1,4 +1,4 @@
{ lib, buildDunePackage, fetchFromGitLab, sedlex_2, xtmpl }:
{ lib, buildDunePackage, fetchFromGitLab, sedlex, xtmpl }:
buildDunePackage rec {
pname = "higlo";
@ -12,7 +12,7 @@ buildDunePackage rec {
sha256 = "sha256:09hsbwy5asacgh4gdj0vjpy4kzfnq3qji9szbsbyswsf1nbyczir";
};
propagatedBuildInputs = [ sedlex_2 xtmpl ];
propagatedBuildInputs = [ sedlex xtmpl ];
meta = with lib; {
description = "OCaml library for syntax highlighting";

@ -1,5 +1,5 @@
{ lib, buildDunePackage, fetchFromGitLab
, sedlex_2, uunf, uutf
, sedlex, uunf, uutf
}:
buildDunePackage rec {
@ -15,7 +15,7 @@ buildDunePackage rec {
sha256 = "sha256:0zk8nnwcyljkc1a556byncv6cn1vqhk4267z1lm15flh1k7chyax";
};
propagatedBuildInputs = [ sedlex_2 uunf uutf ];
propagatedBuildInputs = [ sedlex uunf uutf ];
meta = {
description = "IRI (RFC3987) native OCaml implementation";

@ -1,4 +1,4 @@
{ lib, stdenv, fetchFromGitHub, ocaml, findlib, which, sedlex_2, easy-format, xmlm, base64 }:
{ lib, stdenv, fetchFromGitHub, ocaml, findlib, which, sedlex, easy-format, xmlm, base64 }:
stdenv.mkDerivation rec {
version = "0.6.15";
@ -13,7 +13,7 @@ stdenv.mkDerivation rec {
};
nativeBuildInputs = [ ocaml findlib which ];
propagatedBuildInputs = [ sedlex_2 xmlm easy-format base64 ];
propagatedBuildInputs = [ sedlex xmlm easy-format base64 ];
strictDeps = true;

@ -1,67 +0,0 @@
{ lib
, fetchFromGitHub
, fetchurl
, buildDunePackage
, ocaml
, gen
, ppxlib
, uchar
}:
if lib.versionOlder ocaml.version "4.08"
then throw "sedlex is not available for OCaml ${ocaml.version}"
else
let
unicodeVersion = "13.0.0";
baseUrl = "https://www.unicode.org/Public/${unicodeVersion}";
DerivedCoreProperties = fetchurl {
url = "${baseUrl}/ucd/DerivedCoreProperties.txt";
sha256 = "0j12x112cd8fpgazkc8izxnhhpia44p1m36ff8yapslxndcmzm55";
};
DerivedGeneralCategory = fetchurl {
url = "${baseUrl}/ucd/extracted/DerivedGeneralCategory.txt";
sha256 = "0w6mkz4w79k23bnmwgfxc4yqc2ypv8ilrjn6nk25hrafksbg00j5";
};
PropList = fetchurl {
url = "${baseUrl}/ucd/PropList.txt";
sha256 = "1ks0585wimygbk2wqi9hqg8gyl25iffvdad5vya1zgsxs8z5lns8";
};
in
buildDunePackage rec {
pname = "sedlex";
version = "2.4";
useDune2 = true;
src = fetchFromGitHub {
owner = "ocaml-community";
repo = "sedlex";
rev = "v${version}";
sha256 = "13g8az4zqg6hrnxmy3qrasslppzlag13dd1dsr8vlpg2vpfmfv6i";
};
propagatedBuildInputs = [
gen uchar ppxlib
];
preBuild = ''
rm src/generator/data/dune
ln -s ${DerivedCoreProperties} src/generator/data/DerivedCoreProperties.txt
ln -s ${DerivedGeneralCategory} src/generator/data/DerivedGeneralCategory.txt
ln -s ${PropList} src/generator/data/PropList.txt
'';
doCheck = true;
dontStrip = true;
meta = {
homepage = "https://github.com/ocaml-community/sedlex";
changelog = "https://github.com/ocaml-community/sedlex/raw/v${version}/CHANGES";
description = "An OCaml lexer generator for Unicode";
license = lib.licenses.mit;
maintainers = [ lib.maintainers.marsam ];
};
}

@ -1,37 +1,63 @@
{ stdenv, lib, fetchFromGitHub, ocaml, findlib, gen, ppx_tools_versioned, ocaml-migrate-parsetree }:
if lib.versionOlder ocaml.version "4.02"
then throw "sedlex is not available for OCaml ${ocaml.version}"
else
{ lib
, fetchFromGitHub
, fetchurl
, buildDunePackage
, ocaml
, gen
, ppxlib
, uchar
}:
let
unicodeVersion = "14.0.0";
baseUrl = "https://www.unicode.org/Public/${unicodeVersion}";
DerivedCoreProperties = fetchurl {
url = "${baseUrl}/ucd/DerivedCoreProperties.txt";
sha256 = "sha256:1g77s8g9443dd92f82pbkim7rk51s7xdwa3mxpzb1lcw8ryxvvg3";
};
DerivedGeneralCategory = fetchurl {
url = "${baseUrl}/ucd/extracted/DerivedGeneralCategory.txt";
sha256 = "sha256:080l3bwwppm7gnyga1hzhd07b55viklimxpdsx0fsxhr8v47krnd";
};
PropList = fetchurl {
url = "${baseUrl}/ucd/PropList.txt";
sha256 = "sha256:08k75jzl7ws9l3sm1ywsj24qa4qvzn895wggdpp5nyj1a2wgvpbb";
};
in
buildDunePackage rec {
pname = "sedlex";
version = "2.5";
stdenv.mkDerivation rec {
pname = "ocaml${ocaml.version}-sedlex";
version = "1.99.5";
minimalOCamlVersion = "4.08";
src = fetchFromGitHub {
owner = "ocaml-community";
repo = "sedlex";
rev = "fb84e1766fc4b29e79ec40029ffee5cdb37b392f";
sha256 = "sha256-VhzlDTYBFXgKWT69PqZYLuHkiaDwzhmyX2XfaqzHFl4=";
rev = "v${version}";
sha256 = "sha256:062a5dvrzvb81l3a9phljrhxfw9nlb61q341q0a6xn65hll3z2wy";
};
nativeBuildInputs = [ ocaml findlib ];
propagatedBuildInputs = [ gen ocaml-migrate-parsetree ppx_tools_versioned ];
strictDeps = true;
propagatedBuildInputs = [
gen uchar ppxlib
];
buildFlags = [ "all" "opt" ];
preBuild = ''
rm src/generator/data/dune
ln -s ${DerivedCoreProperties} src/generator/data/DerivedCoreProperties.txt
ln -s ${DerivedGeneralCategory} src/generator/data/DerivedGeneralCategory.txt
ln -s ${PropList} src/generator/data/PropList.txt
'';
createFindlibDestdir = true;
doCheck = true;
dontStrip = true;
meta = {
homepage = "https://github.com/ocaml-community/sedlex";
changelog = "https://github.com/ocaml-community/sedlex/raw/v${version}/CHANGES";
description = "An OCaml lexer generator for Unicode";
license = lib.licenses.mit;
inherit (ocaml.meta) platforms;
maintainers = [ lib.maintainers.vbgl ];
maintainers = [ lib.maintainers.marsam ];
};
}

@ -1,4 +1,4 @@
{ lib, buildDunePackage, fetchFromGitLab, iri, re, sedlex_2, uutf }:
{ lib, buildDunePackage, fetchFromGitLab, iri, re, sedlex, uutf }:
buildDunePackage rec {
pname = "xtmpl";
@ -12,7 +12,7 @@ buildDunePackage rec {
sha256 = "sha256:0vwj0aayg60wm98d91fg3hmj90730liljy4cn8771dpxvz8m07bw";
};
propagatedBuildInputs = [ iri re sedlex_2 uutf ];
propagatedBuildInputs = [ iri re sedlex uutf ];
meta = with lib; {
description = "XML templating library for OCaml";

@ -13,7 +13,7 @@
buildPythonApplication rec {
pname = "mkdocs-material";
version = "8.2.15";
version = "8.2.16";
format = "setuptools";
disabled = pythonOlder "3.6";
@ -22,7 +22,7 @@ buildPythonApplication rec {
owner = "squidfunk";
repo = pname;
rev = "refs/tags/${version}";
hash = "sha256-6x3ENFPGmtRDMV6YRGlTLCYusmX49LrGBDwicg8sDB0=";
hash = "sha256-ZRk1PGLUg3StD7JhuI+3hRc4lWwEO3CrMUfLSqFVgVk=";
};
propagatedBuildInputs = [

@ -32,14 +32,14 @@
buildPythonPackage rec {
pname = "mlflow";
version = "1.26.0";
version = "1.26.1";
format = "setuptools";
disabled = pythonOlder "3.7";
src = fetchPypi {
inherit pname version;
hash = "sha256-2D1glQkovCY0lN0kfxGeoLigTkkPpij13mTeou7CAw4=";
hash = "sha256-VoBESElY6nG9MU7UICbP2V5kH+6+GFaKMuy/mv6bk9Q=";
};
propagatedBuildInputs = [

@ -19,14 +19,14 @@
buildPythonPackage rec {
pname = "protonvpn-nm-lib";
version = "3.9.0";
version = "3.10.0";
disabled = pythonOlder "3.7";
src = fetchFromGitHub {
owner = "ProtonVPN";
repo = pname;
rev = version;
sha256 = "sha256-yV3xeIyPc2DJj5DOa5PA1MHt00bjJ/Y9zZK77s/XRAA=";
sha256 = "sha256-WVIQ43J01BQzYhEPDHcoAmUvlsaDw0Z7yLQGajVdedU=";
};
propagatedBuildInputs = [

@ -10,14 +10,14 @@
buildPythonPackage rec {
pname = "python-gitlab";
version = "3.4.0";
version = "3.5.0";
format = "setuptools";
disabled = pythonOlder "3.7";
src = fetchPypi {
inherit pname version;
sha256 = "sha256-YYC4HuLyZa2NhBKVahdAtNPOynsori9wff5iN1/tAII=";
sha256 = "sha256-Ka5/ubjJrrLm4ZvS/QSGfpPs169xmXjOaPrAzxFqsw0=";
};
propagatedBuildInputs = [

@ -32,13 +32,14 @@ with py.pkgs;
buildPythonApplication rec {
pname = "checkov";
version = "2.0.1161";
version = "2.0.1162";
format = "setuptools";
src = fetchFromGitHub {
owner = "bridgecrewio";
repo = pname;
rev = version;
hash = "sha256-EJpmJ6/Q5j8olY0hD2wX2zeF0cTwFQuaMsno2zXRfvI=";
hash = "sha256-WE0pND22DucKBSY4rtZfPH9AKgBslCoUOj45Rkd9qBc=";
};
nativeBuildInputs = with py.pkgs; [
@ -63,6 +64,7 @@ buildPythonApplication rec {
docker
dockerfile-parse
dpath
flake8
GitPython
jmespath
jsonpath-ng
@ -95,7 +97,6 @@ buildPythonApplication rec {
postPatch = ''
substituteInPlace setup.py \
--replace "bc-python-hcl2==" "bc-python-hcl2>=" \
--replace "cyclonedx-python-lib>=0.11.0,<1.0.0" "cyclonedx-python-lib>=0.11.0" \
--replace "prettytable>=3.0.0" "prettytable" \
--replace "pycep-parser==0.3.6" "pycep-parser"
'';

@ -18,7 +18,7 @@ stdenv.mkDerivation rec {
install -Dm644 resources/shell/bash-completion $out/share/bash-completion/completions/flow
'';
buildInputs = (with ocamlPackages; [ ocaml findlib ocamlbuild ocaml-migrate-parsetree-2 dtoa core_kernel sedlex_2 ocaml_lwt lwt_log lwt_ppx ppx_deriving ppx_gen_rec visitors wtf8 ])
buildInputs = (with ocamlPackages; [ ocaml findlib ocamlbuild ocaml-migrate-parsetree-2 dtoa core_kernel sedlex ocaml_lwt lwt_log lwt_ppx ppx_deriving ppx_gen_rec visitors wtf8 ])
++ lib.optionals stdenv.isDarwin [ CoreServices ];
meta = with lib; {

@ -2,16 +2,16 @@
buildGoModule rec {
pname = "yq-go";
version = "4.25.1";
version = "4.25.2";
src = fetchFromGitHub {
owner = "mikefarah";
repo = "yq";
rev = "v${version}";
sha256 = "sha256-pop6FOOQoWGpFuvor2a1TP1tevw7+MIfm0PevGO9nUs=";
sha256 = "sha256-yvFh1wPOsmQLGTLrMG7dwcEukFpelP183Xa2n2XiHlQ=";
};
vendorSha256 = "sha256-R40zU0jOc/eIFVDsWG3+4o51iro7Sd7jwtyH/fpWVZs=";
vendorSha256 = "sha256-oUpHK6YKjKWTGL2yC1q2hK/K/gK8I+FwTVshTxHBOKI=";
nativeBuildInputs = [ installShellFiles ];

@ -0,0 +1,93 @@
{ lib
, stdenv
, fetchurl
, fetchFromGitHub
, substituteAll
, cmake
, curl
, nasm
, openmpt123
, p7zip
, libgme
, libpng
, SDL2
, SDL2_mixer
, zlib
}:
let
assets_version = "2.2.5";
assets = fetchurl {
url = "https://github.com/mazmazz/SRB2/releases/download/SRB2_assets_220/srb2-${assets_version}-assets.7z";
sha256 = "1m9xf3vraq9nipsi09cyvvfa4i37gzfxg970rnqfswd86z9v6v00";
};
assets_optional = fetchurl {
url = "https://github.com/mazmazz/SRB2/releases/download/SRB2_assets_220/srb2-${assets_version}-optional-assets.7z";
sha256 = "1j29jrd0r1k2bb11wyyl6yv9b90s2i6jhrslnh77qkrhrwnwcdz4";
};
in stdenv.mkDerivation rec {
pname = "srb2";
version = "2.2.10";
src = fetchFromGitHub {
owner = "STJr";
repo = "SRB2";
rev = "SRB2_release_${version}";
sha256 = "03388n094d2yr5si6ngnggbqhm8b2l0s0qvfnkz49li9bd6a81gg";
};
nativeBuildInputs = [
cmake
nasm
p7zip
];
buildInputs = [
curl
libgme
libpng
openmpt123
SDL2
SDL2_mixer
zlib
];
cmakeFlags = [
"-DSRB2_ASSET_DIRECTORY=/build/source/assets"
"-DGME_INCLUDE_DIR=${libgme}/include"
"-DOPENMPT_INCLUDE_DIR=${openmpt123}/include"
"-DSDL2_MIXER_INCLUDE_DIR=${SDL2_mixer}/include/SDL2"
"-DSDL2_INCLUDE_DIR=${SDL2.dev}/include/SDL2"
];
patches = [
./wadlocation.patch
];
postPatch = ''
substituteInPlace src/sdl/i_system.c \
--replace '@wadlocation@' $out
'';
preConfigure = ''
7z x ${assets} -o"/build/source/assets" -aos
7z x ${assets_optional} -o"/build/source/assets" -aos
'';
postInstall = ''
mkdir $out/bin
mv $out/lsdlsrb2-${version} $out/bin/srb2
'';
meta = with lib; {
description = "Sonic Robo Blast 2 is a 3D Sonic the Hedgehog fangame based on a modified version of Doom Legacy";
homepage = "https://www.srb2.org/";
platforms = platforms.linux;
license = licenses.gpl2Plus;
maintainers = with maintainers; [ zeratax ];
};
}

@ -0,0 +1,72 @@
diff --git a/src/sdl/i_system.c b/src/sdl/i_system.c
index 10c0747bf..861f00728 100644
--- a/src/sdl/i_system.c
+++ b/src/sdl/i_system.c
@@ -145,13 +145,7 @@ int TimeFunction(int requested_frequency);
// Locations for searching the srb2.pk3
#if defined (__unix__) || defined(__APPLE__) || defined (UNIXCOMMON)
-#define DEFAULTWADLOCATION1 "/usr/local/share/games/SRB2"
-#define DEFAULTWADLOCATION2 "/usr/local/games/SRB2"
-#define DEFAULTWADLOCATION3 "/usr/share/games/SRB2"
-#define DEFAULTWADLOCATION4 "/usr/games/SRB2"
-#define DEFAULTSEARCHPATH1 "/usr/local/games"
-#define DEFAULTSEARCHPATH2 "/usr/games"
-#define DEFAULTSEARCHPATH3 "/usr/local"
+#define DEFAULTWADLOCATION1 "@wadlocation@"
#elif defined (_WIN32)
#define DEFAULTWADLOCATION1 "c:\\games\\srb2"
#define DEFAULTWADLOCATION2 "\\games\\srb2"
@@ -2812,34 +2806,6 @@ static const char *locateWad(void)
if (((envstr = I_GetEnv("SRB2WADDIR")) != NULL) && isWadPathOk(envstr))
return envstr;
-#ifndef NOCWD
- I_OutputMsg(",.");
- // examine current dir
- strcpy(returnWadPath, ".");
- if (isWadPathOk(returnWadPath))
- return NULL;
-#endif
-
-
-#ifdef CMAKECONFIG
-#ifndef NDEBUG
- I_OutputMsg(","CMAKE_ASSETS_DIR);
- strcpy(returnWadPath, CMAKE_ASSETS_DIR);
- if (isWadPathOk(returnWadPath))
- {
- return returnWadPath;
- }
-#endif
-#endif
-
-#ifdef __APPLE__
- OSX_GetResourcesPath(returnWadPath);
- I_OutputMsg(",%s", returnWadPath);
- if (isWadPathOk(returnWadPath))
- {
- return returnWadPath;
- }
-#endif
// examine default dirs
#ifdef DEFAULTWADLOCATION1
@@ -2884,16 +2850,7 @@ static const char *locateWad(void)
if (isWadPathOk(returnWadPath))
return returnWadPath;
#endif
-#ifndef NOHOME
- // find in $HOME
- I_OutputMsg(",HOME");
- if ((envstr = I_GetEnv("HOME")) != NULL)
- {
- WadPath = searchWad(envstr);
- if (WadPath)
- return WadPath;
- }
-#endif
+
#ifdef DEFAULTSEARCHPATH1
// find in /usr/local
I_OutputMsg(", in:"DEFAULTSEARCHPATH1);

@ -0,0 +1,88 @@
{ lib
, stdenv
, fetchurl
, fetchFromGitHub
, substituteAll
, cmake
, curl
, nasm
, unzip
, libgme
, libpng
, SDL2
, SDL2_mixer
, zlib
}:
let
release_tag = "v1.3";
installer = fetchurl {
url = "https://github.com/STJr/Kart-Public/releases/download/${release_tag}/srb2kart-v13-Installer.exe";
sha256 = "0bk36y7wf6xfdg6j0b8qvk8671hagikzdp5nlfqg478zrj0qf6cs";
};
in stdenv.mkDerivation rec {
pname = "srb2kart";
version = "1.3.0";
src = fetchFromGitHub {
owner = "STJr";
repo = "Kart-Public";
rev = release_tag;
sha256 = "131g9bmc9ihvz0klsc3yzd0pnkhx3mz1vzm8y7nrrsgdz5278y49";
};
nativeBuildInputs = [
cmake
nasm
unzip
];
buildInputs = [
curl
libgme
libpng
SDL2
SDL2_mixer
zlib
];
cmakeFlags = [
#"-DSRB2_ASSET_DIRECTORY=/build/source/assets"
"-DGME_INCLUDE_DIR=${libgme}/include"
"-DSDL2_MIXER_INCLUDE_DIR=${SDL2_mixer}/include/SDL2"
"-DSDL2_INCLUDE_DIR=${SDL2.dev}/include/SDL2"
];
patches = [
./wadlocation.patch
];
postPatch = ''
substituteInPlace src/sdl/i_system.c \
--replace '@wadlocation@' $out
'';
preConfigure = ''
mkdir assets/installer
pushd assets/installer
unzip ${installer} "*.kart" srb2.srb
popd
'';
postInstall = ''
mkdir -p $out/bin $out/share/games/SRB2Kart
mv $out/srb2kart* $out/bin/
mv $out/*.kart $out/share/games/SRB2Kart
'';
meta = with lib; {
description = "SRB2Kart is a classic styled kart racer";
homepage = "https://mb.srb2.org/threads/srb2kart.25868/";
platforms = platforms.linux;
license = licenses.gpl2Plus;
maintainers = with maintainers; [ viric ];
};
}

@ -0,0 +1,61 @@
diff --git a/src/sdl/i_system.c b/src/sdl/i_system.c
index 51f708d0..c4d971f7 100644
--- a/src/sdl/i_system.c
+++ b/src/sdl/i_system.c
@@ -139,7 +139,7 @@ typedef LPVOID (WINAPI *p_MapViewOfFile) (HANDLE, DWORD, DWORD, DWORD, SIZE_T);
// Locations for searching the srb2.srb
#if defined (__unix__) || defined(__APPLE__) || defined (UNIXCOMMON)
-#define DEFAULTWADLOCATION1 "/usr/local/share/games/SRB2Kart"
+#define DEFAULTWADLOCATION1 "@wadlocation@"
#define DEFAULTWADLOCATION2 "/usr/local/games/SRB2Kart"
#define DEFAULTWADLOCATION3 "/usr/share/games/SRB2Kart"
#define DEFAULTWADLOCATION4 "/usr/games/SRB2Kart"
@@ -3646,47 +3646,6 @@ static const char *locateWad(void)
if (((envstr = I_GetEnv("SRB2WADDIR")) != NULL) && isWadPathOk(envstr))
return envstr;
-#ifndef NOCWD
- I_OutputMsg(",.");
- // examine current dir
- strcpy(returnWadPath, ".");
- if (isWadPathOk(returnWadPath))
- return NULL;
-#endif
-
-
-#ifdef DEFAULTDIR
- I_OutputMsg(",HOME/" DEFAULTDIR);
- // examine user jart directory
- if ((envstr = I_GetEnv("HOME")) != NULL)
- {
- sprintf(returnWadPath, "%s" PATHSEP DEFAULTDIR, envstr);
- if (isWadPathOk(returnWadPath))
- return returnWadPath;
- }
-#endif
-
-
-#ifdef CMAKECONFIG
-#ifndef NDEBUG
- I_OutputMsg(","CMAKE_ASSETS_DIR);
- strcpy(returnWadPath, CMAKE_ASSETS_DIR);
- if (isWadPathOk(returnWadPath))
- {
- return returnWadPath;
- }
-#endif
-#endif
-
-#ifdef __APPLE__
- OSX_GetResourcesPath(returnWadPath);
- I_OutputMsg(",%s", returnWadPath);
- if (isWadPathOk(returnWadPath))
- {
- return returnWadPath;
- }
-#endif
-
// examine default dirs
#ifdef DEFAULTWADLOCATION1
I_OutputMsg(","DEFAULTWADLOCATION1);

@ -17,12 +17,12 @@ index 834f1cd..10ab1e7 100644
* parameter given to the kernel. So reserving memory from low to high
* satisfies this constraint again. Reserving 1M at 0x02600000-0x02700000 for
* the DTB leaves rest of the free RAM to the initrd starting at 0x02700000.
* Even with the smallest possible CPU-GPU memory split of the CPU getting
* only 64M, the remaining 25M starting at 0x02700000 should allow quite
* large initrds before they start colliding with U-Boot.
*/
#define ENV_MEM_LAYOUT_SETTINGS \
@ -33,10 +33,10 @@ index 834f1cd..10ab1e7 100644
- "pxefile_addr_r=0x02500000\0" \
- "fdt_addr_r=0x02600000\0" \
- "ramdisk_addr_r=0x02700000\0"
+ "scriptaddr=0x03500000\0" \
+ "pxefile_addr_r=0x03600000\0" \
+ "fdt_addr_r=0x03700000\0" \
+ "ramdisk_addr_r=0x03800000\0"
+ "scriptaddr=0x04500000\0" \
+ "pxefile_addr_r=0x04600000\0" \
+ "fdt_addr_r=0x04700000\0" \
+ "ramdisk_addr_r=0x04800000\0"
#if CONFIG_IS_ENABLED(CMD_MMC)
#define BOOT_TARGET_MMC(func) \

@ -1,18 +1,25 @@
{ lib, buildGoModule, fetchFromGitHub }:
{ lib, buildGoModule, fetchFromGitHub, nixosTests }:
buildGoModule rec {
pname = "mimir";
version = "2.0.0";
version = "2.1.0";
src = fetchFromGitHub {
rev = "${pname}-${version}";
owner = "grafana";
repo = pname;
sha256 = "T1lljhC/TS3eoIc9AFo9Oy9/COM/XnfcwtkU618YCdM=";
sha256 = "sha256-n7Vzp/GQIC+Mryu9SycMZ3ScPo5O+5tA4TdigpKzmLU=";
};
vendorSha256 = null;
subPackages = [ "cmd/mimir" ];
subPackages = [
"cmd/mimir"
"cmd/mimirtool"
];
passthru.tests = {
inherit (nixosTests) grafana-mimir;
};
ldflags = let t = "github.com/grafana/mimir/pkg/util/version";
in [

@ -0,0 +1,21 @@
{ lib, ... }:
lib.recurseIntoAttrs {
# https://github.com/NixOS/nixpkgs/issues/175196
allowPkgsInPermittedInsecurePackages =
let pkgs = import ../.. {
config = {
permittedInsecurePackages =
tempAllow pkgs.authy "2.1.0" [ "electron-9.4.4" ];
};
};
# Allow with forgetting
tempAllow = p: v: pa:
lib.optionals (lib.assertMsg (p.version == v) "${p.name} is no longer at version ${v}, consider removing the tempAllow") pa;
# For this test we don't _really_ care about the version though,
# only about evaluation strictness
tempAllowAlike = p: v: pa: builtins.seq v builtins.seq p.version pa;
in pkgs.hello;
}

@ -22,6 +22,8 @@ with pkgs;
cc-wrapper-libcxx-9 = callPackage ./cc-wrapper { stdenv = llvmPackages_9.libcxxStdenv; };
stdenv-inputs = callPackage ./stdenv-inputs { };
config = callPackage ./config.nix { };
haskell = callPackage ./haskell { };
cc-multilib-gcc = callPackage ./cc-wrapper/multilib.nix { stdenv = gccMultiStdenv; };

@ -59,7 +59,7 @@ stdenv.mkDerivation {
ocamlPackages.xmlm ocamlPackages.ocaml_pcre
ocamlPackages.camomile
ocamlPackages.fdkaac
ocamlPackages.srt ocamlPackages.sedlex_2 ocamlPackages.menhir ocamlPackages.menhirLib
ocamlPackages.srt ocamlPackages.sedlex ocamlPackages.menhir ocamlPackages.menhirLib
];
hardeningDisable = [ "format" "fortify" ];

@ -11,11 +11,11 @@
# Note: when upgrading this package, please run the list-missing-tools.sh script as described below!
python3Packages.buildPythonApplication rec {
pname = "diffoscope";
version = "213";
version = "214";
src = fetchurl {
url = "https://diffoscope.org/archive/diffoscope-${version}.tar.bz2";
sha256 = "sha256-l2kdV1QUGsS3D6Y/b485iDmQcBNIzaBywxhqfRDINX8=";
sha256 = "sha256-ap+U9b+pCfQ2UwqQDTx0mQ0nvXJsl4D89Q/Ecl7w+8c=";
};
outputs = [ "out" "man" ];

@ -1,35 +0,0 @@
{ buildGoPackage, go-bindata, fetchFromGitHub }:
buildGoPackage rec {
pname = "ngrok";
version = "1.7.1";
rev = version;
goPackagePath = "ngrok";
src = fetchFromGitHub {
inherit rev;
owner = "inconshreveable";
repo = "ngrok";
sha256 = "1r4nc9knp0nxg4vglg7v7jbyd1nh1j2590l720ahll8a4fbsx5a4";
};
goDeps = ./deps.nix;
nativeBuildInputs = [ go-bindata ];
preConfigure = ''
sed -e '/jteeuwen\/go-bindata/d' \
-e '/export GOPATH/d' \
-e 's/go get/#go get/' \
-e 's|bin/go-bindata|go-bindata|' -i Makefile
make assets BUILDTAGS=release
export sourceRoot=$sourceRoot/src/ngrok
'';
tags = [ "release" ];
meta = {
homepage = "https://ngrok.com/";
};
}

@ -1,101 +0,0 @@
[
{
goPackagePath = "github.com/gorilla/websocket";
fetch = {
type = "git";
url = "https://github.com/gorilla/websocket";
rev = "a622679ebd7a3b813862379232f645f8e690e43f";
sha256 = "1nc9jbcmgya1i6dmf6sbcqsnxi9hbjg6dz1z0k7zmc6xdwlq0y4q";
};
}
{
goPackagePath = "github.com/rcrowley/go-metrics";
fetch = {
type = "git";
url = "https://github.com/rcrowley/go-metrics";
rev = "1ce93efbc8f9c568886b2ef85ce305b2217b3de3";
sha256 = "06gg72krlmd0z3zdq6s716blrga95pyj8dc2f2psfbknbkyrkfqa";
};
}
{
goPackagePath = "github.com/inconshreveable/go-vhost";
fetch = {
type = "git";
url = "https://github.com/inconshreveable/go-vhost";
rev = "c4c28117502e4bf00960c8282b2d1c51c865fe2c";
sha256 = "1rway6sls6fl2s2jk20ajj36rrlzh9944ncc9pdd19kifix54z32";
};
}
{
goPackagePath = "code.google.com/p/log4go";
fetch = {
type = "git";
url = "https://github.com/ccpaging/log4go";
rev = "cb4cc51cd03958183d3b637d0750497d88c2f7a8";
sha256 = "0l9f86zzhla9hq35q4xhgs837283qrm4gxbp5lrwwls54ifiq7k2";
};
}
{
goPackagePath = "github.com/daviddengcn/go-colortext";
fetch = {
type = "git";
url = "https://github.com/daviddengcn/go-colortext";
rev = "13eaeb896f5985a1ab74ddea58707a73d875ba57";
sha256 = "0618xs9lc5xfp5zkkb5j47dr7i30ps3zj5fj0zpv8afqh2cc689x";
};
}
{
goPackagePath = "gopkg.in/yaml.v1";
fetch = {
type = "git";
url = "https://github.com/go-yaml/yaml";
rev = "b0c168ac0cf9493da1f9bb76c34b26ffef940b4a";
sha256 = "0jbdy41pplf2d1j24qwr8gc5qsig6ai5ch8rwgvg72kq9q0901cy";
};
}
{
goPackagePath = "github.com/inconshreveable/mousetrap";
fetch = {
type = "git";
url = "https://github.com/inconshreveable/mousetrap";
rev = "9dbb96d2c3a964935b0870b5abaea13c98b483aa";
sha256 = "1f9g8vm18qv1rcb745a4iahql9vfrz0jni9mnzriab2wy1pfdl5b";
};
}
{
goPackagePath = "github.com/nsf/termbox-go";
fetch = {
type = "git";
url = "https://github.com/nsf/termbox-go";
rev = "9aecf65084a5754f12d27508fa2e6ed56851953b";
sha256 = "16sak07bgvmax4zxfrd4jia1dgygk733xa8vk8cdx28z98awbfsh";
};
}
{
goPackagePath = "gopkg.in/inconshreveable/go-update.v0";
fetch = {
type = "git";
url = "https://github.com/inconshreveable/go-update";
rev = "d8b0b1d421aa1cbf392c05869f8abbc669bb7066";
sha256 = "0cvkik2w368fzimx3y29ncfgw7004qkbdf2n3jy5czvzn35q7dpa";
};
}
{
goPackagePath = "github.com/kardianos/osext";
fetch = {
type = "git";
url = "https://github.com/kardianos/osext";
rev = "29ae4ffbc9a6fe9fb2bc5029050ce6996ea1d3bc";
sha256 = "1mawalaz84i16njkz6f9fd5jxhcbxkbsjnav3cmqq2dncv2hyv8a";
};
}
{
goPackagePath = "github.com/kr/binarydist";
fetch = {
type = "git";
url = "https://github.com/kr/binarydist";
rev = "9955b0ab8708602d411341e55fffd7e0700f86bd";
sha256 = "11wncbbbrdcxl5ff3h6w8vqfg4bxsf8709mh6vda0cv236flkyn3";
};
}
]

@ -2,16 +2,16 @@
rustPlatform.buildRustPackage rec {
pname = "shadowsocks-rust";
version = "1.14.2";
version = "1.14.3";
src = fetchFromGitHub {
rev = "v${version}";
owner = "shadowsocks";
repo = pname;
sha256 = "sha256-zWiC1GhrI3gcXhr8JpAbFF6t7N6aBSho33FMu8bhF2o=";
sha256 = "sha256-tRiziyCw1Qpm22RtZHeKt4VFReJidFHsPxPSjxIA3hA=";
};
cargoSha256 = "sha256-nSKeFLWTHhtmlvA9MV6NpupKJo3d1jKpTBI5H8cHJ9s=";
cargoSha256 = "sha256-snnzNb1yJ8L5pMvNNEIf5hZOpFV6DKOWGtGP1T3YTWg=";
RUSTC_BOOTSTRAP = 1;

@ -8650,8 +8650,6 @@ with pkgs;
ngrok-2 = callPackage ../tools/networking/ngrok-2 { };
ngrok-1 = callPackage ../tools/networking/ngrok-1 { };
nifi = callPackage ../servers/web-apps/nifi { };
nitter = callPackage ../servers/nitter { };
@ -32256,6 +32254,10 @@ with pkgs;
springLobby = callPackage ../games/spring/springlobby.nix { };
srb2 = callPackage ../games/srb2 { };
srb2kart = callPackage ../games/srb2kart { };
ssl-cert-check = callPackage ../tools/admin/ssl-cert-check { };
stardust = callPackage ../games/stardust { };

@ -128,7 +128,7 @@ let
in {
freeformType =
let t = lib.types.attrsOf lib.types.raw;
let t = lib.types.lazyAttrsOf lib.types.raw;
in t // {
merge = loc: defs:
let r = t.merge loc defs;

@ -1322,8 +1322,6 @@ let
sedlex = callPackage ../development/ocaml-modules/sedlex { };
sedlex_2 = callPackage ../development/ocaml-modules/sedlex/2.nix { };
semaphore-compat = callPackage ../development/ocaml-modules/semaphore-compat { };
@@ -3646,47 +3646,6 @@ static const char *locateWad(void)
* parameter given to the kernel. So reserving memory from low to high
- * satisfies this constraint again. Reserving 1M at 0x02600000-0x02700000 for
- * the DTB leaves rest of the free RAM to the initrd starting at 0x02700000.
+ * satisfies this constraint again. Reserving 1M at 0x03700000-0x03800000 for
+ * the DTB leaves rest of the free RAM to the initrd starting at 0x03800000.
+ * satisfies this constraint again. Reserving 1M at 0x04700000-0x04800000 for
+ * the DTB leaves rest of the free RAM to the initrd starting at 0x04800000.
* Even with the smallest possible CPU-GPU memory split of the CPU getting
@@ -3646,47 +3646,6 @@ static const char *locateWad(void)
* Even with the smallest possible CPU-GPU memory split of the CPU getting
- * only 64M, the remaining 25M starting at 0x02700000 should allow quite
- * large initrds before they start colliding with U-Boot.
+ * only 64M, the remaining 9M starting at 0x03800000 should allow reasonably
+ * only 64M, the remaining 8M starting at 0x04800000 should allow reasonably
+ * sized initrds before they start colliding with U-Boot.
*/
#define ENV_MEM_LAYOUT_SETTINGS \
sha = callPackage ../development/ocaml-modules/sha { };

Loading…
Cancel
Save